Yeo 2011 Atlas


Notes
-----
This atlas provides a labeling of some cortical voxels in the MNI152
space.

Four versions of the atlas are available, according to the cortical
model (thick or thin cortical surface) and to the number of regions
considered (7 or 17).

Content
-------
    :'anat': Background anatomical image for reference and visualization
    :'thin_7': Cortical parcelation into 7 regions, thin cortical model
    :'thin_17': Cortical parcelation into 17 regions, thin cortical model
    :'thick_7': Cortical parcelation into 17 regions, thick cortical model
    :'thick_17': Cortical parcelation into 17 regions, thick cortical model
    :'colors_7': Text file for the coloring of 7-regions parcellation
    :'colors_17': Text file for the coloring of 17-regions parcellation


References
----------
For more information on this dataset's structure, see
http://surfer.nmr.mgh.harvard.edu/fswiki/CorticalParcellation_Yeo2011

Yeo BT, Krienen FM, Sepulcre J, Sabuncu MR, Lashkari D, Hollinshead M,
Roffman JL, Smoller JW, Zollei L., Polimeni JR, Fischl B, Liu H,
Buckner RL. The organization of the human cerebral cortex estimated by
intrinsic functional connectivity. J Neurophysiol 106(3):1125-65, 2011.

Licence: unknown.
